@@ -13,10 +13,11 @@ def parse_args():
     parser.add_argument('command', type=str, default='start',
                         help='"start": start rpc server, "config": config rpc server')
 
-    parser.add_argument('-sid', type=str, default='default', help='Server ID')
-    parser.add_argument('-host', type=str, default='127.0.0.1', help='Host IP')
-    parser.add_argument('-port', type=int, default=9900, help='Host Port')
+    parser.add_argument('-sid', type=str, default='', help='Server ID')  # default
+    parser.add_argument('-host', type=str, default='', help='Host IP')  # 127.0.0.1
+    parser.add_argument('-port', type=int, default=None, help='Host Port')  # 9900
     parser.add_argument('-key', type=str, default=None, help='Host Authkey')
+    parser.add_argument('-ds', type=str, default='', help='Default Server ID')  # default
     parser.add_argument('-f', type=str, default=None, help='Load config File(copy for ~/.adk)')
 
     return parser.parse_args()
@@ -28,10 +29,10 @@ def main():
     if cmd == 'config':
         from adk.rpc.rpc_cfg import set_rpc_config
         set_rpc_config(host=params.host, port=params.port, key=params.key,
-                       server_id=params.sid, filename=params.f)
+                       server_id=params.sid, default_server=params.ds, filename=params.f)
     elif cmd == 'start':
         from adk.rpc.rpc_manager import start_rpc_server
-        start_rpc_server()
+        start_rpc_server(server_id=params.sid)
 
 
 if __name__ == '__main__':
